@@ -13,7 +13,6 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """ CLI root-level commands; Subcommands are imported at the bottom of file
 """
 import json
@@ -29,8 +28,7 @@ import re
 
 from claradm import api
 
-import logging 
-
+import logging
 
 output_format_help = """The 'human' mode gives a tabular or list view depending
 on the fetched data, but often needs a lot of horizontal space to display
@@ -104,13 +102,10 @@ class APIHelper:
         file_handler.setLevel(logging.DEBUG)
         console_handler = logging.StreamHandler()
         console_handler.setLevel(
-            logging.DEBUG if verbose > 1 else
-            logging.INFO if verbose == 1 else
-            logging.WARNING
+            logging.DEBUG if verbose > 1 else logging.INFO if verbose == 1 else logging.WARNING
         )
         file_formatter = logging.Formatter(
-            "%(asctime)s %(name)-8s %(levelname)-7s %(message)s",
-            datefmt="%Y-%m-%d %H:%M:%S"
+            "%(asctime)s %(name)-8s %(levelname)-7s %(message)s", datefmt="%Y-%m-%d %H:%M:%S"
         )
         console_formatter = logging.Formatter("%(levelname)-5s %(message)s")
         console_handler.setFormatter(console_formatter)
@@ -125,8 +120,7 @@ class APIHelper:
                 self.output_format = name
                 self.formatter = formatter
                 break
-        self.log.debug("Formatter in use: %s - %s", self.output_format,
-                       self.formatter)
+        self.log.debug("Formatter in use: %s - %s", self.output_format, self.formatter)
         return True
 
     def load(self):
@@ -151,20 +145,17 @@ class APIHelper:
         else:  # we use the configured default output format
             self._set_formatter(self.config["format"])
         self.api = api.SynapseAdmin(
-            self.log,
-            self.config["user"], self.config["token"],
-            self.config["base_url"], self.config["admin_path"],
-            self.config["timeout"], self.requests_debug
+            self.log, self.config["user"], self.config["token"], self.config["base_url"],
+            self.config["admin_path"], self.config["timeout"], self.requests_debug
         )
         self.matrix_api = api.Matrix(
-            self.log,
-            self.config["user"], self.config["token"],
-            self.config["base_url"], self.config["matrix_path"],
-            self.config["timeout"], self.requests_debug
+            self.log, self.config["user"], self.config["token"], self.config["base_url"],
+            self.config["matrix_path"], self.config["timeout"], self.requests_debug
         )
         self.misc_request = api.MiscRequest(
             self.log,
-            self.config["timeout"], self.requests_debug,
+            self.config["timeout"],
+            self.requests_debug,
         )
         return True
 
@@ -174,14 +165,15 @@ class APIHelper:
         try:
             os.makedirs(os.path.dirname(self.config_path), exist_ok=True)
             with open(self.config_path, "w") as handle:
-                yaml.dump(config, handle, default_flow_style=False,
-                          allow_unicode=True)
+                yaml.dump(config, handle, default_flow_style=False, allow_unicode=True)
             if os.name == "posix":
                 click.echo("Restricting access to config file to user only.")
                 os.chmod(self.config_path, 0o600)
             else:
-                click.echo(f"Unsupported OS, please adjust permissions of "
-                           f"{self.config_path} manually")
+                click.echo(
+                    f"Unsupported OS, please adjust permissions of "
+                    f"{self.config_path} manually"
+                )
 
             return True
         except Exception as error:
@@ -216,41 +208,26 @@ class APIHelper:
 
         if self.config["server_discovery"] == "well-known":
             if "localhost" in self.config["base_url"]:
-                echo(
-                    "Trying to fetch homeserver name via localhost..."
-                )
-                return self.matrix_api.server_name_keys_api(
-                    self.config["base_url"]
-                )
+                echo("Trying to fetch homeserver name via localhost...")
+                return self.matrix_api.server_name_keys_api(self.config["base_url"])
             else:
-                echo(
-                    "Trying to fetch federation URI via well-known resource..."
-                )
-                federation_uri = self.misc_request.federation_uri_well_known(
-                    uri
-                )
+                echo("Trying to fetch federation URI via well-known resource...")
+                federation_uri = self.misc_request.federation_uri_well_known(uri)
                 if not federation_uri:
                     return None
             return self.matrix_api.server_name_keys_api(federation_uri)
         elif self.config["server_discovery"] == "dns":
-            echo(
-                "Trying to fetch federation URI via DNS SRV record..."
-            )
+            echo("Trying to fetch federation URI via DNS SRV record...")
             hostname = urlparse(uri).hostname
             try:
-                record = dns.resolver.query(
-                    "_matrix._tcp.{}".format(hostname),
-                    "SRV"
-                )
+                record = dns.resolver.query("_matrix._tcp.{}".format(hostname), "SRV")
             except Exception as error:
                 self.log.error(
-                    "resolving Matrix delegation for %s: %s: %s",
-                    hostname, type(error).__name__, error
+                    "resolving Matrix delegation for %s: %s: %s", hostname,
+                    type(error).__name__, error
                 )
             else:
-                federation_uri = "https://{}:{}".format(
-                    record[0].target, record[0].port
-                )
+                federation_uri = "https://{}:{}".format(record[0].target, record[0].port)
                 return self.matrix_api.server_name_keys_api(federation_uri)
         else:
             self.log.error("Unknown server_discovery mode. "
@@ -276,8 +253,10 @@ class APIHelper:
             self.log.debug("A proper MXID was passed.")
             return user_id
         elif re.match(r"^@?[-./=\w]+:?$", user_id):
-            self.log.debug("A proper localpart was passed, generating MXID "
-                           "for local homeserver.")
+            self.log.debug(
+                "A proper localpart was passed, generating MXID "
+                "for local homeserver."
+            )
             localpart = re.sub("[@:]", "", user_id)
             mxid = "@{}:{}".format(localpart, self.retrieve_homeserver_name())
             return mxid
@@ -288,32 +267,48 @@ class APIHelper:
 
 
 @click.group(
-    invoke_without_command=False,
-    context_settings=dict(help_option_names=["-h", "--help"]))
+    invoke_without_command=False, context_settings=dict(help_option_names=["-h", "--help"])
+)
 @click.version_option()
 @click.option(
-    "--verbose", "-v", count=True, default=False,
-    help="Enable INFO (-v) or DEBUG (-vv) logging on console.")
+    "--verbose",
+    "-v",
+    count=True,
+    default=False,
+    help="Enable INFO (-v) or DEBUG (-vv) logging on console."
+)
 @click.option(
-    "--no-confirm", "--batch", "--yes", "--non-interactive", "--scripting",
-    default=False, is_flag=True,
+    "--no-confirm",
+    "--batch",
+    "--yes",
+    "--non-interactive",
+    "--scripting",
+    default=False,
+    is_flag=True,
     help="""Enable non-interactive mode. Use with caution! This will:
 
     \b
         - Disable all interactive prompts.
         - Disable automatic translation of unix timestamps to human readable
           formats.
-    """)
+    """
+)
 @click.option(
-    "--output", "-o", default="",
-    type=click.Choice(["yaml", "json", "minified", "human", "pprint",
-                       "y", "j", "m", "h", "p", ""]),
+    "--output",
+    "-o",
+    default="",
+    type=click.Choice(["yaml", "json", "minified", "human", "pprint", "y", "j", "m", "h", "p", ""]),
     show_choices=True,
-    help=f"Override default output format. {output_format_help}")
+    help=f"Override default output format. {output_format_help}"
+)
 @click.option(
-    "--config-file", "-c", type=click.Path(),
+    "--config-file",
+    "-c",
+    type=click.Path(),
     default="~/.config/claradm.yaml",
-    help="Configuration file path.", show_default=True)
+    help="Configuration file path.",
+    show_default=True
+)
 @click.pass_context
 def root(ctx, verbose, no_confirm, output, config_file):
     """ the Matrix-Synapse admin CLI
@@ -332,37 +327,51 @@ def root(ctx, verbose, no_confirm, output, config_file):
 
 @root.command(name="config")
 @click.option(
-    "--user", "-u", "user_", type=str,
-    help="Admin user allowed to access the Synapse Admin API's.")
+    "--user", "-u", "user_", type=str, help="Admin user allowed to access the Synapse Admin API's."
+)
+@click.option("--token", "-t", type=str, help="The Admin user's access token.")
 @click.option(
-    "--token", "-t", type=str,
-    help="The Admin user's access token.")
-@click.option(
-    "--base-url", "-b", type=str,
+    "--base-url",
+    "-b",
+    type=str,
     help="""The base URL Synapse is running on. Typically this is
     https://localhost:8008 or https://localhost:8448. If Synapse is
     configured to expose its Admin API's to the outside world it might as
-    well be something like this: https://example.org:8448""")
+    well be something like this: https://example.org:8448"""
+)
 @click.option(
-    "--admin-path", "-p", type=str,
+    "--admin-path",
+    "-p",
+    type=str,
     help="""The path Synapse provides its Admin API's, usually the default fits
-    most installations.""")
+    most installations."""
+)
 @click.option(
-    "--matrix-path", "-m", type=str,
+    "--matrix-path",
+    "-m",
+    type=str,
     help="""The path Clarion provides the regular Matrix APIs, usually the
-    default fits most installations.""")
+    default fits most installations."""
+)
 @click.option(
-    "--timeout", "-w", type=int,
+    "--timeout",
+    "-w",
+    type=int,
     help="""The time in seconds claradm should wait for responses from admin
-    APIs or Matrix APIs. The default is 7 seconds. """)
+    APIs or Matrix APIs. The default is 7 seconds. """
+)
 @click.option(
-    "--output", "-o", type=click.Choice([
-        "yaml", "json", "minified", "human", "pprint"]),
+    "--output",
+    "-o",
+    type=click.Choice(["yaml", "json", "minified", "human", "pprint"]),
     help=f"""How claradm displays data by default. {output_format_help} The
     default output format can always be overridden by using the global
-    --output/-o switch (eg 'claradm -o pprint user list').""")
+    --output/-o switch (eg 'claradm -o pprint user list')."""
+)
 @click.option(
-    "--server-discovery", "-d", type=click.Choice(["well-known", "dns"]),
+    "--server-discovery",
+    "-d",
+    type=click.Choice(["well-known", "dns"]),
     help="""The method used for discovery of "the own homeserver name". Since
     none of the currently existing Admin API endpoints provide this
     information, the federation API among other things is asked for help. If
@@ -378,26 +387,35 @@ def root(ctx, verbose, no_confirm, output, config_file):
     fetching of the homeserver name is only executed when a claradm subcommand
     requires it (eg. like some of the media and user subcommands do), and the
     "homeserver" directive in the config is set to "auto-retrieval".
-    """)
+    """
+)
 @click.option(
-    "--homeserver", "-n", type=str,
+    "--homeserver",
+    "-n",
+    type=str,
     help="""Clarion homeserver hostname. Usually matrix.DOMAIN or DOMAIN. The
     default value 'auto-retrieval' will try to discover the name using the
     method set by --server-discovery."""
 )
 @click.option(
-    "--ssl-verify", "-i",  is_flag=True, show_default=True,
+    "--ssl-verify",
+    "-i",
+    is_flag=True,
+    show_default=True,
     help="""Whether or not SSL certificates should be verified. Set to False
     to allow self-signed certifcates."""
 )
 @click.pass_obj
-def config_cmd(helper, user_, token, base_url, admin_path, matrix_path,
-               output, timeout, server_discovery, homeserver, ssl_verify):
+def config_cmd(
+    helper, user_, token, base_url, admin_path, matrix_path, output, timeout, server_discovery,
+    homeserver, ssl_verify
+):
     """ Modify claradm's configuration.
 
     Configuration details are generally always asked interactively. Command
     line options override the suggested defaults in the prompts.
     """
+
     def get_redacted_token_prompt(cli_token):
         redacted = "NOT SET"  # Show as empty: [].
         if cli_token:
@@ -409,27 +427,17 @@ def config_cmd(helper, user_, token, base_url, admin_path, matrix_path,
         return f"Clarion admin user token [{redacted}]"
 
     if helper.no_confirm:
-        if not all([user, token, base_url, admin_path, matrix_path,
-                    output, timeout, server_discovery, homeserver,
-                    ssl_verify]):
-            click.echo(
-                "Missing config options for non-interactive configuration!"
-            )
+        if not all([user, token, base_url, admin_path, matrix_path, output, timeout,
+                    server_discovery, homeserver, ssl_verify]):
+            click.echo("Missing config options for non-interactive configuration!")
             raise SystemExit(3)
         else:
             click.echo("Saving to config file.")
-            if helper.write_config({
-                "user": user_,
-                "token": token,
-                "base_url": base_url,
-                "admin_path": admin_path,
-                "matrix_path": matrix_path,
-                "format": output,
-                "timeout": timeout,
-                "server_discovery": server_discovery,
-                "homeserver": homeserver,
-                "ssl_verify": ssl_verify
-            }):
+            if helper.write_config({"user": user_, "token": token, "base_url": base_url,
+                                    "admin_path": admin_path, "matrix_path": matrix_path,
+                                    "format": output, "timeout": timeout,
+                                    "server_discovery": server_discovery, "homeserver": homeserver,
+                                    "ssl_verify": ssl_verify}):
                 raise SystemExit(0)
             else:
                 raise SystemExit(4)
@@ -437,48 +445,53 @@ def config_cmd(helper, user_, token, base_url, admin_path, matrix_path,
     click.echo("Running configurator...")
     helper.write_config({
         "user": click.prompt(
-            "Clarion admin user name",
-            default=user_ if user_ else helper.config.get("user", user_)),
+            "Clarion admin user name", default=user_ if user_ else helper.config.get("user", user_)
+        ),
         "token": click.prompt(
             get_redacted_token_prompt(token),
             default=token if token else helper.config.get("token", token),
-            show_default=False, hide_input=True),
+            show_default=False,
+            hide_input=True
+        ),
         "base_url": click.prompt(
             "Clarion base URL",
-            default=base_url if base_url else helper.config.get(
-                "base_url", base_url)),
+            default=base_url if base_url else helper.config.get("base_url", base_url)
+        ),
         "admin_path": click.prompt(
             "Synapse Admin API path",
-            default=admin_path if admin_path else helper.config.get(
-                "admin_path", admin_path)),
+            default=admin_path if admin_path else helper.config.get("admin_path", admin_path)
+        ),
         "matrix_path": click.prompt(
             "Matrix API path",
-            default=matrix_path if matrix_path else helper.config.get(
-                "matrix_path", matrix_path)),
+            default=matrix_path if matrix_path else helper.config.get("matrix_path", matrix_path)
+        ),
         "format": click.prompt(
             "Default output format",
             default=output if output else helper.config.get("format", output),
-            type=click.Choice([
-                "yaml", "json", "minified", "human", "pprint"])),
+            type=click.Choice(["yaml", "json", "minified", "human", "pprint"])
+        ),
         "timeout": click.prompt(
             "Default http timeout",
-            default=timeout if timeout else helper.config.get(
-                "timeout", timeout)),
+            default=timeout if timeout else helper.config.get("timeout", timeout)
+        ),
         "homeserver": click.prompt(
             "Homeserver name (\"auto-retrieval\" or the domain part in your "
             "MXID)",
-            default=homeserver if homeserver else helper.config.get(
-                "homeserver", homeserver)),
+            default=homeserver if homeserver else helper.config.get("homeserver", homeserver)
+        ),
         "ssl_verify": click.prompt(
             "Verify certificate",
             type=bool,
-            default=ssl_verify if ssl_verify else helper.config.get(
-                "ssl_verify", ssl_verify)),
+            default=ssl_verify if ssl_verify else helper.config.get("ssl_verify", ssl_verify)
+        ),
         "server_discovery": click.prompt(
             "Server discovery mode (used with homeserver name auto-retrieval)",
-            default=server_discovery if server_discovery else helper.config.get(  # noqa: E501
-                "server_discovery", server_discovery),
-            type=click.Choice(["well-known", "dns"])),
+            default=server_discovery if server_discovery else
+            helper.config.get(  # noqa: E501
+                "server_discovery", server_discovery
+            ),
+            type=click.Choice(["well-known", "dns"])
+        ),
     })
     if not helper.load():
         click.echo("Configuration incomplete, quitting.")
@@ -498,4 +511,4 @@ def version(helper):
 
 
 # Import additional commands
-from claradm.cli import account, clarion, setup, service, room, user, media, group, history, matrix, regtok, notice, raw  # noqa: F401, E402, E501
+from claradm.cli import account, clarion, firewall, setup, service, room, user, media, group, history, matrix, regtok, notice, raw, restart  # noqa: F401, E402, E501
